Learn R Programming

mitools (version 2.7)

MIextract: Extract a parameter from a list of results

Description

Used to extract parameter estimates and standard errors from lists produced by with.imputationList.

Usage

MIextract(results, expr, fun)

Value

A list

Arguments

results

A list of objects

expr

an expression

fun

a function of one argument

Details

If expr is supplied, it is evaluated in each element of results. Otherwise each element of results is passed as an argument to fun.

See Also

with.imputationList, MIcombine

Examples

Run this code
data(smi)
models<-with(smi, glm(drinkreg~wave*sex,family=binomial()))

betas<-MIextract(models,fun=coef)
vars<-MIextract(models, fun=vcov)
summary(MIcombine(betas,vars))

Run the code above in your browser using DataLab